#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : mi.
# @File         : dba_app
# @Time         : 2020/6/18 7:30 下午
# @Author       : yuanjie
# @Email        : yuanjie@xiaomi.com
# @Software     : PyCharm
# @Description  : 





#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : mi.
# @File         : demo_app
# @Time         : 2020/10/20 3:57 下午
# @Author       : yuanjie
# @Email        : yuanjie@xiaomi.com
# @Software     : PyCharm
# @Description  : 


from mi.app.base_app import App


@app.get("/get1")
def xxxx(request: Request):
    print(request.query_params.get('a', 'xxxxxxx'))
    return {"Hello": "world"}


if __name__ == '__main__':
    import socket
    import uvicorn

    me = socket.gethostname() == 'yuanjie-Mac.local'
    main_file = __file__.split('/')[-1].split('.')[0]

    # app参数必须是个字符串才能开启热更新
    uvicorn.run(app=f"{main_file}:app", host='0.0.0.0', port=8000, workers=1, debug=True, reload=True)



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : mi.
# @File         : demo
# @Time         : 2020/10/26 2:58 下午
# @Author       : yuanjie
# @Email        : yuanjie@xiaomi.com
# @Software     : PyCharm
# @Description  : 



语文 = float(input("语文："))
数学 = float(input("数学："))
英语 = float(input("英语："))

print(0.5 * 语文 + 0.3 * 数学 + 0.2 * 英语)



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : tql-App.
# @File         : Scheduler
# @Time         : 2019-12-10 13:50
# @Author       : yuanjie
# @Email        : yuanjie@xiaomi.com
# @Software     : PyCharm
# @Description  :

from datetime import datetime, timedelta
from apscheduler.schedulers.background import BackgroundScheduler
from apscheduler.events import EVENT_JOB_EXECUTED, EVENT_JOB_ERROR


class Scheduler(object):
    """learning: https://blog.csdn.net/somezz/article/details/83104368"""

    def __init__(self):
        """
        trigger='date': 一次性任务，即只执行一次任务。
            next_run_time (datetime|str) – 下一次任务执行时间
            timezone (datetime.tzinfo|str) – 时区

        trigger='interval': 循环任务，即按照时间间隔执行任务。
            seconds (int) – 秒
            minutes (int) – 分钟
            hours (int) – 小时
            days (int) – 日
            weeks (int) – 周
            start_date (datetime|str) – 启动开始时间
            end_date (datetime|str) – 最后结束时间
            timezone (datetime.tzinfo|str) – 时区

        trigger='cron': 定时任务，即在每个时间段执行任务。None为0
            second (int|str) – 秒 (0-59)
            minute (int|str) – 分钟 (0-59)
            hour (int|str) – 小时 (0-23)
            day_of_week (int|str) – 一周中的第几天 (0-6 or mon,tue,wed,thu,fri,sat,sun)
            day (int|str) – 日 (1-31)
            week (int|str) – 一年中的第几周 (1-53)
            month (int|str) – 月 (1-12)
            year (int|str) – 年(四位数)
            start_date (datetime|str) – 最早开始时间
            end_date (datetime|str) – 最晚结束时间
            timezone (datetime.tzinfo|str) – 时区

        """
        self.scheduler = BackgroundScheduler()

    def add_job(self, func, trigger='interval', args=None, kwargs=None,
                max_instances=1,
                next_run_time=None,
                **trigger_args):
        """
        The ``trigger`` argument can either be:
          #. the alias name of the trigger (e.g. ``date``, ``interval`` or ``cron``), in which case
            any extra keyword arguments to this method are passed on to the trigger's constructor
          #. an instance of a trigger class

        :param func: callable (or a textual reference to one) to run at the given time
        :param str|apscheduler.triggers.base.BaseTrigger trigger: trigger that determines when
            ``func`` is called
        :param list|tuple args: list of positional arguments to call func with
        :param dict kwargs: dict of keyword arguments to call func with

        next_run_time:
            默认立即执行
            可设置第一次的执行时间
            None为暂停job
        """
        assert callable(func), "TODO: callable function"

        self.scheduler.add_job(func, trigger, args, kwargs,
                               max_instances=max_instances,
                               next_run_time=next_run_time,
                               **trigger_args)

    def add_listener(self, callback):
        assert callable(callback), "TODO: callable function"
        self.scheduler.add_listener(callback, EVENT_JOB_EXECUTED | EVENT_JOB_ERROR)

    def start(self):
        self.scheduler.start()


if __name__ == '__main__':
    # import logging
    #
    # logging.basicConfig(level=logging.INFO,
    #                     format='%(asctime)s %(filename)s[line:%(lineno)d] %(levelname)s %(message)s',
    #                     datefmt='%Y-%m-%d %H:%M:%S',
    #                     filename='log.txt',
    #                     filemode='a')
    # scheduler.scheduler._logger = logging

    def task1(x):
        print(x)
        import logging
        import time
        logging.warning(f'Task1: {time.ctime()}')


    def task2():
        import logging
        import time
        logging.warning(f'Task2: {time.ctime()}')


    def task3():
        import logging
        import time
        logging.warning(f'Task3: {time.ctime()}')


    def my_listener(event):
        if event.exception:
            # print(event.traceback)
            print('任务出错了！！！！！！')
        else:
            print('任务照常运行...')


    scheduler = Scheduler()
    scheduler.add_job(task1, 'interval', seconds=66666, args=('定时任务',))
    scheduler.add_job(task2, 'interval', seconds=66666)
    scheduler.add_job(task3, 'cron', second=None, minute='*', hour='*')

    # scheduler.add_listener(my_listener)
    scheduler.start()

    while 1:
        pass



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : mi.
# @File         : zk_utils
# @Time         : 2020/7/2 5:26 下午
# @Author       : yuanjie
# @Email        : yuanjie@xiaomi.com
# @Software     : PyCharm
# @Description  : 


from kazoo.client import KazooClient

zk = KazooClient(hosts="tjwqstaging.zk.hadoop.srv:11000")
zk.start()

# 注册节点
zk.create('/mipush/biz/search',b'this is test',makepath=True)

# 获取节点及值
zk.get_children('/mipush/biz')
zk.get('/mipush/biz/search')

# 更改节点的值
# zk.set


import socket

ip = socket.gethostbyname(socket.gethostname())
biz = 'search'
scenes = 'autopush'

# session 中断后自动删除该节点, 实例重启后自动更新节点
zk.create(f'/mipush/ann/{biz}/{scenes}/{ip}', b'create ip nodes', makepath=True, ephemeral=True)


#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : mi.
# @File         : EmailApp
# @Time         : 2020-03-06 09:41
# @Author       : yuanjie
# @Email        : yuanjie@xiaomi.com
# @Software     : PyCharm
# @Description  : 

import time
import pandas as pd
from typing import Optional
from fastapi import FastAPI, Form, Depends, File, UploadFile, Body
from pydantic import BaseModel
from starlette.staticfiles import StaticFiles
from starlette.requests import Request
from starlette.responses import \
    RedirectResponse, FileResponse, HTMLResponse, PlainTextResponse
from starlette.status import *
import numpy as np


ROUTE = ""
app = FastAPI(
    debug=True,
    openapi_url=f"{ROUTE}/openapi.json",
    docs_url=f"{ROUTE}/docs",
    redoc_url=f"{ROUTE}/redoc",
    swagger_ui_oauth2_redirect_url=f"{ROUTE}/docs/oauth2-redirect"
)
d = {}

@app.get("/get")
def xxxx(request: Request):
    print(request.query_params.get('a', 'xxxxxxx'))
    return {"Hello": d}

@app.post("/post")
def xxxx(request: Request, kwargs: dict):
    print(request.query_params)
    print(kwargs)
    return {"Hello": "World"}

@app.get("/gett")
def read_root():
    return {'a': np.array([1, 2, 3]).tolist()}


@app.get("/report")
def read_root():
    # return HTMLResponse(content=open("/Users/yuanjie/Desktop/notebook/your_report.html").read())
    return PlainTextResponse(content=open("/Users/yuanjie/Desktop/notebook/your_report.html").read())


@app.get("/reports")
def read_root():
    print(1)
    return FileResponse(path="/Users/yuanjie/Desktop/notebook/your_report.html", filename='downloadName')


@app.get("/view/{file}")
def read_root(file):
    return FileResponse(path=f"/Users/yuanjie/Desktop/notebook/{file}")


from fastapi.staticfiles import StaticFiles

app.mount("/static", StaticFiles(directory="static"), name="static")

# HTMLResponse(content="htmlString")
# HTMLResponse(content=open("/Users/yuanjie/Desktop/notebook/your_report.html").read())
# FileResponse(path="/Users/yuanjie/Desktop/notebook/your_report.html", filename=None) # 等价于上方
# FileResponse(path="./file.txt", filename='downloadName')
# https://fastapi.tiangolo.com/tutorial/background-tasks/

if __name__ == '__main__':

    d['a']=111111111
    import os
    import socket

    me = socket.gethostname() == 'yuanjie-Mac.local'

    uvicorn = "uvicorn" if me else "/opt/soft/python3/bin/uvicorn"

    main_file = __file__.split('/')[-1].split('.')[0]

    # --reload测试环境
    os.system(f"uvicorn {main_file}:app --reload --host 0.0.0.0 --port 9000")
